@@ -29,6 +29,7 @@ func init() {
 		"config":                "Query or define _murex_ runtime settings",
 		"cpuarch":               "Output the hosts CPU architecture",
 		"cpucount":              "Output the number of CPU cores available on your host",
+		"datetime":              "A date and/or time conversion tool (like `printf` but for date and time values)",
 		"debug":                 "Debugging information",
 		"die":                   "Terminate murex with an exit number of 1",
 		"err":                   "Print a line to the STDERR",
@@ -154,6 +155,7 @@ func init() {
 		"!config":               "config",
 		"cpuarch":               "cpuarch",
 		"cpucount":              "cpucount",
+		"datetime":              "datetime",
 		"debug":                 "debug",
 		"die":                   "die",
 		"err":                   "err",
