@@ -72,10 +72,20 @@ func matchDynamic(f *Flags, partial string, args dynamicArgs, act *AutoCompleteT
 			fStdin = lang.F_NO_STDIN
 		}
 
+		// don't share incomplete parameters with dynamic autocompletion blocks
+		params := act.ParsedTokens.Parameters
+		switch len(params) {
+		case 0: // do nothing
+		case 1:
+			params = []string{}
+		default:
+			params = params[:len(params)-1]
+		}
+
 		// Execute the dynamic code block
 		fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NEW_MODULE | lang.F_BACKGROUND | fStdin | lang.F_CREATE_STDOUT | lang.F_NO_STDERR)
 		fork.Name.Set(args.exe)
-		fork.Parameters.DefineParsed(args.params)
+		fork.Parameters.DefineParsed(params)
 		fork.FileRef = ExesFlagsFileRef[args.exe]
 		if f.ExecCmdline && !act.ParsedTokens.Unsafe {
 			fork.Stdin = cmdlineStdout
