@@ -6,6 +6,7 @@ import (
 	"os"
 
 	"github.com/lmorg/murex/builtins/pipes/term"
+	"github.com/lmorg/murex/config/defaults"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/ref"
 	"github.com/lmorg/murex/utils"
@@ -68,3 +69,10 @@ func execSource(source []rune, sourceRef *ref.Source) {
 		os.Exit(exitNum)
 	}
 }
+
+func defaultProfile() {
+	os.Stderr.WriteString("Loading default profile" + utils.NewLineString)
+	source := defaults.DefaultMurexProfile()
+	ref := ref.History.AddSource("(builtin)", "source/builtin", []byte(string(source)))
+	execSource(defaults.DefaultMurexProfile(), ref)
+}
