@@ -42,7 +42,10 @@ for f in *.md; do
 done
 find docs -name "*.md" -exec gen/website/find-exec.sh {} \;
 
-
+sed -i '0,/<img src/s//<img class="no-border" src/;
+        0,/<img src/s//<img class="no-border" src/;
+        0,/<img src/s//<img class="no-border" src/;' \
+        README.html
 
 echo "Compiling WebAssembly...."
 
